@@ -1,21 +1,30 @@
 
+from __future__ import unicode_literals
+from __future__ import print_function
 import elixir
 
 from reahl.sqlalchemysupport import Session, metadata
 
 from reahl.web.fw import UserInterface
-from reahl.web.ui import TwoColumnPage, Form, TextInput, LabelledBlockInput, Button, Panel, P, H, InputGroup
+from reahl.web.ui import Button
+from reahl.web.ui import Form
+from reahl.web.ui import InputGroup
+from reahl.web.ui import LabelledBlockInput
+from reahl.web.ui import P
+from reahl.web.ui import Panel
+from reahl.web.ui import TextInput
+from reahl.web.ui import TwoColumnPage
 from reahl.component.modelinterface import exposed, EmailField, Field, Event, Action
 
 
 class PersistenceUI(UserInterface):
     def assemble(self):
-        self.define_view(u'/', title=u'Persistence demo', page=HomePage.factory())
+        self.define_view('/', title='Persistence demo', page=HomePage.factory())
 
 
 class HomePage(TwoColumnPage):
     def __init__(self, view):
-        super(HomePage, self).__init__(view, style=u'basic')
+        super(HomePage, self).__init__(view, style='basic')
 
         self.main.add_child(CommentForm(view))
 
@@ -24,7 +33,7 @@ class HomePage(TwoColumnPage):
 
 
 class Comment(elixir.Entity):
-    elixir.using_options(session=Session, metadata=metadata, tablename=u'features_comment')
+    elixir.using_options(session=Session, metadata=metadata, tablename='features_comment')
     elixir.using_mapper_options(save_on_init=False)
     
     email_address = elixir.Field(elixir.UnicodeText)
@@ -32,12 +41,12 @@ class Comment(elixir.Entity):
     
     @exposed
     def fields(self, fields):
-        fields.email_address = EmailField(label=u'Email address', required=True)
-        fields.text          = Field(label=u'Comment', required=True)
+        fields.email_address = EmailField(label='Email address', required=True)
+        fields.text          = Field(label='Comment', required=True)
 
     @exposed
     def events(self, events):
-        events.submit = Event(label=u'Submit', action=Action(self.submit))
+        events.submit = Event(label='Submit', action=Action(self.submit))
 
     def submit(self):
         Session.add(self)
@@ -45,10 +54,10 @@ class Comment(elixir.Entity):
 
 class CommentForm(Form):
     def __init__(self, view):
-        super(CommentForm, self).__init__(view, u'myform')
+        super(CommentForm, self).__init__(view, 'myform')
 
         new_comment = Comment()
-        grouped_inputs = self.add_child(InputGroup(view, label_text=u'Leave a comment'))
+        grouped_inputs = self.add_child(InputGroup(view, label_text='Leave a comment'))
         grouped_inputs.add_child( LabelledBlockInput(TextInput(self, new_comment.fields.email_address)) )
         grouped_inputs.add_child( LabelledBlockInput(TextInput(self, new_comment.fields.text)) )
         self.define_event_handler(new_comment.events.submit)
@@ -58,6 +67,6 @@ class CommentForm(Form):
 class CommentBox(Panel):
     def __init__(self, view, comment):
         super(CommentBox, self).__init__(view)
-        self.add_child(P(view, text=u'By %s: %s' % (comment.email_address, comment.text)))
+        self.add_child(P(view, text='By %s: %s' % (comment.email_address, comment.text)))
         
 
