@@ -1,9 +1,9 @@
 
+from __future__ import unicode_literals
+from __future__ import print_function
 import elixir
-from sqlalchemy.orm.exc import NoResultFound
 
 from reahl.sqlalchemysupport import Session, metadata
-from reahl.elixirsupport import session_scoped
 
 from reahl.web.fw import UserInterface, UrlBoundView, CannotCreate
 from reahl.web.ui import TwoColumnPage, Form, TextInput, LabelledBlockInput, Button, Panel, P, H, InputGroup, HMenu,\
@@ -17,7 +17,7 @@ class Address(elixir.Entity):
     elixir.using_options(session=Session, metadata=metadata)
     elixir.using_mapper_options(save_on_init=False)
     
-    address_book  = elixir.ManyToOne(u'reahl.doc.examples.tutorial.access.access.AddressBook')
+    address_book  = elixir.ManyToOne('reahl.doc.examples.tutorial.access.access.AddressBook')
     email_address = elixir.Field(elixir.UnicodeText)
     name          = elixir.Field(elixir.UnicodeText)
 
@@ -30,14 +30,14 @@ class Address(elixir.Entity):
 
     @exposed
     def fields(self, fields):
-        fields.name = Field(label=u'Name', required=self.can_be_added(), writable=Action(self.can_be_added))
-        fields.email_address = EmailField(label=u'Email', required=True, writable=Action(self.can_be_edited))
+        fields.name = Field(label='Name', required=self.can_be_added(), writable=Action(self.can_be_added))
+        fields.email_address = EmailField(label='Email', required=True, writable=Action(self.can_be_edited))
 
-    @exposed(u'save', u'update', u'edit')
+    @exposed('save', 'update', 'edit')
     def events(self, events):
-        events.save = Event(label=u'Save', action=Action(self.save))
-        events.update = Event(label=u'Update')
-        events.edit = Event(label=u'Edit', writable=Action(self.can_be_edited))
+        events.save = Event(label='Save', action=Action(self.save))
+        events.update = Event(label='Update')
+        events.edit = Event(label='Edit', writable=Action(self.can_be_edited))
 
     def save(self):
         Session.add(self)
@@ -76,13 +76,13 @@ class AddressBook(elixir.Entity):
     @exposed
     def fields(self, fields):
         collaborators = [Choice(i.id, IntegerField(label=i.email)) for i in EmailAndPasswordSystemAccount.query.all()]
-        fields.chosen_collaborator = ChoiceField(collaborators, label=u'Choose collaborator')
-        fields.may_edit_address = BooleanField(label=u'May edit existing addresses')
-        fields.may_add_address = BooleanField(label=u'May add new addresses')
+        fields.chosen_collaborator = ChoiceField(collaborators, label='Choose collaborator')
+        fields.may_edit_address = BooleanField(label='May edit existing addresses')
+        fields.may_add_address = BooleanField(label='May add new addresses')
 
-    @exposed(u'add_collaborator')
+    @exposed('add_collaborator')
     def events(self, events):
-        events.add_collaborator = Event(label=u'Share', action=Action(self.add_collaborator))
+        events.add_collaborator = Event(label='Share', action=Action(self.add_collaborator))
 
     def add_collaborator(self):
         chosen_account = EmailAndPasswordSystemAccount.query.filter_by(id=self.chosen_collaborator).one()
@@ -93,11 +93,11 @@ class AddressBook(elixir.Entity):
     @property
     def addresses(self):
         return Address.query.filter_by(address_book=self).all()
-    collaborators = elixir.OneToMany(u'reahl.doc.examples.tutorial.access.access.Collaborator', lazy=u'dynamic')
+    collaborators = elixir.OneToMany('reahl.doc.examples.tutorial.access.access.Collaborator', lazy='dynamic')
 
     @property
     def display_name(self):
-        return u'Address book of %s' % self.owner.email
+        return 'Address book of %s' % self.owner.email
 
     def allow(self, account, can_add_addresses=False, can_edit_addresses=False):
         Collaborator.query.filter_by(address_book=self, account=account).delete()
@@ -159,13 +159,13 @@ class Collaborator(elixir.Entity):
 
 class AddressAppPage(TwoColumnPage):
     def __init__(self, view, home_bookmark):
-        super(AddressAppPage, self).__init__(view, style=u'basic')
+        super(AddressAppPage, self).__init__(view, style='basic')
 
         user_session = UserSession.for_current_session()
         if user_session.is_logged_in():
             logged_in_as = user_session.account.email
         else:
-            logged_in_as = u'Not logged in'
+            logged_in_as = 'Not logged in'
 
         self.header.add_child(P(view, text=logged_in_as))
         self.header.add_child(HMenu.from_bookmarks(view, [home_bookmark]))
@@ -173,7 +173,7 @@ class AddressAppPage(TwoColumnPage):
 
 class LoginForm(Form):
     def __init__(self, view, accounts):
-        super(LoginForm, self).__init__(view, u'login')
+        super(LoginForm, self).__init__(view, 'login')
         
         if self.exception:
             self.add_child(ErrorFeedbackMessage(view, self.exception.as_user_message()))
@@ -187,7 +187,7 @@ class LoginForm(Form):
 
 class LogoutForm(Form):
     def __init__(self, view, accounts):
-        super(LogoutForm, self).__init__(view, u'logout')
+        super(LogoutForm, self).__init__(view, 'logout')
         self.define_event_handler(accounts.events.log_out_event)
         self.add_child(Button(self, accounts.events.log_out_event))
 
@@ -223,7 +223,7 @@ class AddressBookPanel(Panel):
     	self.address_book = address_book
         super(AddressBookPanel, self).__init__(view)
         
-        self.add_child(H(view, 1, text=u'Addresses in %s' % address_book.display_name))
+        self.add_child(H(view, 1, text='Addresses in %s' % address_book.display_name))
         self.add_child(HMenu.from_bookmarks(view, self.menu_bookmarks(address_book_ui)))
         self.add_children([AddressBox(view, address) for address in address_book.addresses])
 
@@ -234,9 +234,9 @@ class AddressBookPanel(Panel):
 
 class EditAddressForm(Form):
     def __init__(self, view, address):
-        super(EditAddressForm, self).__init__(view, u'edit_form')
+        super(EditAddressForm, self).__init__(view, 'edit_form')
 
-        grouped_inputs = self.add_child(InputGroup(view, label_text=u'Edit address'))
+        grouped_inputs = self.add_child(InputGroup(view, label_text='Edit address'))
         grouped_inputs.add_child(LabelledBlockInput(TextInput(self, address.fields.name)))
         grouped_inputs.add_child(LabelledBlockInput(TextInput(self, address.fields.email_address)))
 
@@ -245,11 +245,11 @@ class EditAddressForm(Form):
 
 class AddAddressForm(Form):
     def __init__(self, view, address_book):
-        super(AddAddressForm, self).__init__(view, u'add_form')
+        super(AddAddressForm, self).__init__(view, 'add_form')
 
         new_address = Address(address_book=address_book)
 
-        grouped_inputs = self.add_child(InputGroup(view, label_text=u'Add an address'))
+        grouped_inputs = self.add_child(InputGroup(view, label_text='Add an address'))
         grouped_inputs.add_child(LabelledBlockInput(TextInput(self, new_address.fields.name)))
         grouped_inputs.add_child(LabelledBlockInput(TextInput(self, new_address.fields.email_address)))
 
@@ -258,10 +258,10 @@ class AddAddressForm(Form):
 
 class AddressBox(Form):
     def __init__(self, view, address):
-        form_name = u'address_%s' % address.id
+        form_name = 'address_%s' % address.id
         super(AddressBox, self).__init__(view, form_name)
 
-        par = self.add_child(P(view, text=u'%s: %s ' % (address.name, address.email_address)))
+        par = self.add_child(P(view, text='%s: %s ' % (address.name, address.email_address)))
         par.add_child(Button(self, address.events.edit.with_arguments(address_id=address.id)))
 
 
@@ -270,7 +270,7 @@ class AddressBookView(UrlBoundView):
         address_book = AddressBook.by_id(address_book_id, CannotCreate())
 
         self.title = address_book.display_name
-        self.set_slot(u'main', AddressBookPanel.factory(address_book, address_book_ui))
+        self.set_slot('main', AddressBookPanel.factory(address_book, address_book_ui))
         self.read_check = address_book.is_visible
 
 
@@ -278,19 +278,19 @@ class AddAddressView(UrlBoundView):
     def assemble(self, address_book_id=None):
         address_book = AddressBook.by_id(address_book_id, CannotCreate())
 
-        self.title = u'Add to %s' % address_book.display_name
-        self.set_slot(u'main', AddAddressForm.factory(address_book))
+        self.title = 'Add to %s' % address_book.display_name
+        self.set_slot('main', AddAddressForm.factory(address_book))
         self.write_check = address_book.can_be_added_to
 
 
 class AddCollaboratorForm(Form):
     def __init__(self, view, address_book):
-        super(AddCollaboratorForm, self).__init__(view, u'add_collaborator_form')
+        super(AddCollaboratorForm, self).__init__(view, 'add_collaborator_form')
 
-        grouped_inputs = self.add_child(InputGroup(view, label_text=u'Add a collaborator'))
+        grouped_inputs = self.add_child(InputGroup(view, label_text='Add a collaborator'))
         grouped_inputs.add_child(LabelledBlockInput(SelectInput(self, address_book.fields.chosen_collaborator)))
 
-        rights_inputs = grouped_inputs.add_child(InputGroup(view, label_text=u'Rights'))
+        rights_inputs = grouped_inputs.add_child(InputGroup(view, label_text='Rights'))
         rights_inputs.add_child(LabelledBlockInput(CheckboxInput(self, address_book.fields.may_edit_address)))
         rights_inputs.add_child(LabelledBlockInput(CheckboxInput(self, address_book.fields.may_add_address)))
 
@@ -301,8 +301,8 @@ class AddCollaboratorView(UrlBoundView):
     def assemble(self, address_book_id=None):
         address_book = AddressBook.by_id(address_book_id, CannotCreate())
 
-        self.title = u'Add collaborator to %s' % address_book.display_name
-        self.set_slot(u'main', AddCollaboratorForm.factory(address_book))
+        self.title = 'Add collaborator to %s' % address_book.display_name
+        self.set_slot('main', AddCollaboratorForm.factory(address_book))
         self.read_check = address_book.collaborators_can_be_added
 
 
@@ -310,27 +310,27 @@ class EditAddressView(UrlBoundView):
     def assemble(self, address_id=None):
         address = Address.by_id(address_id, CannotCreate())
 
-        self.title = u'Edit Address for %s' % address.name
-        self.set_slot(u'main', EditAddressForm.factory(address))
+        self.title = 'Edit Address for %s' % address.name
+        self.set_slot('main', EditAddressForm.factory(address))
         self.read_check = address.can_be_edited
 
 
 class AddressBookUI(UserInterface):
     def assemble(self):
 
-        home = self.define_view(u'/', title=u'Address books')
-        home.set_slot(u'main', HomePageWidget.factory(self))
+        home = self.define_view('/', title='Address books')
+        home.set_slot('main', HomePageWidget.factory(self))
       
-        self.address_book_page = self.define_view(u'/address_book', view_class=AddressBookView, 
+        self.address_book_page = self.define_view('/address_book', view_class=AddressBookView, 
                                                   address_book_id=IntegerField(required=True),
                                                   address_book_ui=self)
-        self.add_address_page = self.define_view(u'/add_address', view_class=AddAddressView, 
+        self.add_address_page = self.define_view('/add_address', view_class=AddAddressView, 
                                                  address_book_id=IntegerField(required=True))
 
-        edit_address_page = self.define_view(u'/edit_address', view_class=EditAddressView,
+        edit_address_page = self.define_view('/edit_address', view_class=EditAddressView,
                                              address_id=IntegerField(required=True))
 
-        self.add_collaborator_page = self.define_view(u'/add_collaborator', view_class=AddCollaboratorView, 
+        self.add_collaborator_page = self.define_view('/add_collaborator', view_class=AddCollaboratorView, 
                                                      address_book_id=IntegerField(required=True))
         
         self.define_transition(Address.events.save, self.add_address_page, self.address_book_page)
@@ -343,10 +343,10 @@ class AddressBookUI(UserInterface):
     def get_address_book_bookmark(self, address_book, description=None):
         return self.address_book_page.as_bookmark(self, description=description, address_book_id=address_book.id)
 
-    def get_add_address_bookmark(self, address_book, description=u'Add address'):
+    def get_add_address_bookmark(self, address_book, description='Add address'):
         return self.add_address_page.as_bookmark(self, description=description, address_book_id=address_book.id)
         
-    def get_add_collaborator_bookmark(self, address_book, description=u'Add collaborator'):
+    def get_add_collaborator_bookmark(self, address_book, description='Add collaborator'):
         return self.add_collaborator_page.as_bookmark(self, description=description, address_book_id=address_book.id)
 
 
