@@ -1,12 +1,16 @@
 
+from __future__ import unicode_literals
+from __future__ import print_function
 from reahl.tofu import test, set_up, scenario
 
-from reahl.sqlalchemysupport import Session, metadata
+from reahl.sqlalchemysupport import Session
 
 from reahl.web_dev.fixtures import WebFixture
 from reahl.webdev.tools import Browser, XPath
 
-from reahl.doc.examples.tutorial.access.access import AddressBookUI, AddressBook, Collaborator, Address
+from reahl.doc.examples.tutorial.access.access import Address
+from reahl.doc.examples.tutorial.access.access import AddressBook
+from reahl.doc.examples.tutorial.access.access import AddressBookUI
 from reahl.systemaccountmodel import EmailAndPasswordSystemAccount
 
 
@@ -14,9 +18,9 @@ class AccessFixture(WebFixture):
     def new_browser(self):
         return Browser(self.new_wsgi_app(site_root=AddressBookUI))
         
-    password = u'bobbejaan'
+    password = 'bobbejaan'
 
-    def new_account(self, email=u'johndoe@some.org'):
+    def new_account(self, email='johndoe@some.org'):
         account = EmailAndPasswordSystemAccount(email=email)
         account.set_new_password(account.email, self.password)
         account.activate()
@@ -27,13 +31,13 @@ class AccessFixture(WebFixture):
         return AddressBook(owner=owner)
 
     def new_other_account(self):
-        return self.new_account(email=u'other@some.org')
+        return self.new_account(email='other@some.org')
         
     def new_other_address_book(self):
         return self.new_address_book(owner=self.other_account)
 
     def is_on_address_book_page_of(self, email):
-        return self.browser.title == u'Address book of %s' % email
+        return self.browser.title == 'Address book of %s' % email
 
     def do_demo_setup(self):
         DemoFixture().do_demo_setup()
@@ -47,31 +51,31 @@ class DemoFixture(AccessFixture):
     def do_demo_setup(self):
         self.address_book
         john = self.account
-        jane = self.new_account(email=u'janedoe@some.org')
+        jane = self.new_account(email='janedoe@some.org')
         jane_book = self.new_address_book(owner=jane)
-        someone = self.new_account(email=u'someone@some.org')
+        someone = self.new_account(email='someone@some.org')
         someone_book = self.new_address_book(owner=someone)
-        someone_else = self.new_account(email=u'someoneelse@some.org')
+        someone_else = self.new_account(email='someoneelse@some.org')
         someone_else_book = self.new_address_book(owner=someone_else)
 
         jane_book.allow(john, can_add_addresses=True, can_edit_addresses=True)
         someone_book.allow(john, can_add_addresses=False, can_edit_addresses=True)
         someone_else_book.allow(john, can_add_addresses=False, can_edit_addresses=False)
         
-        Address(address_book=jane_book, email_address=u'friend1@some.org', name=u'Friend1').save()
-        Address(address_book=jane_book, email_address=u'friend2@some.org', name=u'Friend2').save()
-        Address(address_book=jane_book, email_address=u'friend3@some.org', name=u'Friend3').save()
-        Address(address_book=jane_book, email_address=u'friend4@some.org', name=u'Friend4').save()
+        Address(address_book=jane_book, email_address='friend1@some.org', name='Friend1').save()
+        Address(address_book=jane_book, email_address='friend2@some.org', name='Friend2').save()
+        Address(address_book=jane_book, email_address='friend3@some.org', name='Friend3').save()
+        Address(address_book=jane_book, email_address='friend4@some.org', name='Friend4').save()
 
-        Address(address_book=someone_book, email_address=u'friend11@some.org', name=u'Friend11').save()
-        Address(address_book=someone_book, email_address=u'friend12@some.org', name=u'Friend12').save()
-        Address(address_book=someone_book, email_address=u'friend13@some.org', name=u'Friend13').save()
-        Address(address_book=someone_book, email_address=u'friend14@some.org', name=u'Friend14').save()
+        Address(address_book=someone_book, email_address='friend11@some.org', name='Friend11').save()
+        Address(address_book=someone_book, email_address='friend12@some.org', name='Friend12').save()
+        Address(address_book=someone_book, email_address='friend13@some.org', name='Friend13').save()
+        Address(address_book=someone_book, email_address='friend14@some.org', name='Friend14').save()
 
-        Address(address_book=someone_else_book, email_address=u'friend21@some.org', name=u'Friend21').save()
-        Address(address_book=someone_else_book, email_address=u'friend22@some.org', name=u'Friend22').save()
-        Address(address_book=someone_else_book, email_address=u'friend23@some.org', name=u'Friend23').save()
-        Address(address_book=someone_else_book, email_address=u'friend24@some.org', name=u'Friend24').save()
+        Address(address_book=someone_else_book, email_address='friend21@some.org', name='Friend21').save()
+        Address(address_book=someone_else_book, email_address='friend22@some.org', name='Friend22').save()
+        Address(address_book=someone_else_book, email_address='friend23@some.org', name='Friend23').save()
+        Address(address_book=someone_else_book, email_address='friend24@some.org', name='Friend24').save()
         Session.flush()
         Session.commit()
 
@@ -94,10 +98,10 @@ def separate_address_books(fixture):
     assert address_book.addresses == []
     assert other_address_book.addresses == []
 
-    address1 = Address(address_book=address_book, email_address=u'friend1@some.org', name=u'Friend1')
-    address2 = Address(address_book=address_book, email_address=u'friend2@some.org', name=u'Friend2')
+    address1 = Address(address_book=address_book, email_address='friend1@some.org', name='Friend1')
+    address2 = Address(address_book=address_book, email_address='friend2@some.org', name='Friend2')
 
-    address3 = Address(address_book=other_address_book, email_address=u'friend3@some.org', name=u'Friend3')
+    address3 = Address(address_book=other_address_book, email_address='friend3@some.org', name='Friend3')
 
     for address in [address1, address2, address3]:
         address.save()
@@ -115,7 +119,7 @@ def collaborators(fixture):
     address_book = fixture.address_book
     other_address_book = fixture.other_address_book
 
-    unrelated_account = fixture.new_account(email=u'unrelated@some.org')
+    unrelated_account = fixture.new_account(email='unrelated@some.org')
     unrelated_address_book = fixture.new_address_book(owner=unrelated_account)
     
     other_address_book.allow(account)
@@ -127,7 +131,7 @@ def collaborators(fixture):
 
     # Getting a list of visible AddressBooks (for populating the screen)
     books = AddressBook.address_books_visible_to(account)
-    assert set(books) == set([address_book, other_address_book])
+    assert set(books) == {address_book, other_address_book}
 
 
 @test(AccessFixture)
@@ -172,13 +176,13 @@ def logging_in(fixture):
     other_address_book = fixture.other_address_book
     other_address_book.allow(account)
 
-    browser.open(u'/')
-    browser.type(XPath.input_labelled(u'Email'), u'johndoe@some.org')
-    browser.type(XPath.input_labelled(u'Password'), fixture.password)
-    browser.click(XPath.button_labelled(u'Log in'))
+    browser.open('/')
+    browser.type(XPath.input_labelled('Email'), 'johndoe@some.org')
+    browser.type(XPath.input_labelled('Password'), fixture.password)
+    browser.click(XPath.button_labelled('Log in'))
     
-    assert browser.is_element_present(XPath.link_with_text(u'Address book of johndoe@some.org'))
-    assert browser.is_element_present(XPath.link_with_text(u'Address book of other@some.org'))
+    assert browser.is_element_present(XPath.link_with_text('Address book of johndoe@some.org'))
+    assert browser.is_element_present(XPath.link_with_text('Address book of other@some.org'))
 
 
 @test(AccessFixture)
@@ -189,25 +193,25 @@ def edit_and_add_own(fixture):
     address_book = fixture.address_book
 
     fixture.log_in(browser=browser, system_account=account)
-    browser.open(u'/')
+    browser.open('/')
     
-    browser.click(XPath.link_with_text(u'Address book of johndoe@some.org'))
+    browser.click(XPath.link_with_text('Address book of johndoe@some.org'))
     
     # add
-    browser.click(XPath.link_with_text(u'Add address'))
-    browser.type(XPath.input_labelled(u'Name'), u'Someone')
-    browser.type(XPath.input_labelled(u'Email'), u'someone@some.org')
-    browser.click(XPath.button_labelled(u'Save'))
+    browser.click(XPath.link_with_text('Add address'))
+    browser.type(XPath.input_labelled('Name'), 'Someone')
+    browser.type(XPath.input_labelled('Email'), 'someone@some.org')
+    browser.click(XPath.button_labelled('Save'))
 
-    assert browser.is_element_present(XPath.paragraph_containing(u'Someone: someone@some.org'))
+    assert browser.is_element_present(XPath.paragraph_containing('Someone: someone@some.org'))
 
     # edit
-    browser.click(XPath.button_labelled(u'Edit'))
-    browser.type(XPath.input_labelled(u'Name'), u'Else')
-    browser.type(XPath.input_labelled(u'Email'), u'else@some.org')
-    browser.click(XPath.button_labelled(u'Update'))
+    browser.click(XPath.button_labelled('Edit'))
+    browser.type(XPath.input_labelled('Name'), 'Else')
+    browser.type(XPath.input_labelled('Email'), 'else@some.org')
+    browser.click(XPath.button_labelled('Update'))
 
-    assert browser.is_element_present(XPath.paragraph_containing(u'Else: else@some.org'))
+    assert browser.is_element_present(XPath.paragraph_containing('Else: else@some.org'))
     
 
 # ------- Tests added for access control
@@ -222,37 +226,37 @@ def see_other(fixture):
 
     other_address_book = fixture.other_address_book
     other_address_book.allow(account)
-    Address(address_book=other_address_book, email_address=u'friend@some.org', name=u'Friend').save()
+    Address(address_book=other_address_book, email_address='friend@some.org', name='Friend').save()
 
     fixture.log_in(browser=browser, system_account=account)
-    browser.open(u'/')
+    browser.open('/')
 
-    browser.click(XPath.link_with_text(u'Address book of other@some.org'))
+    browser.click(XPath.link_with_text('Address book of other@some.org'))
 
-    assert browser.is_element_present(XPath.paragraph_containing(u'Friend: friend@some.org'))
+    assert browser.is_element_present(XPath.paragraph_containing('Friend: friend@some.org'))
 
     # Case: can only see
-    assert not browser.is_element_enabled(XPath.link_with_text(u'Add address'))
-    assert not browser.is_element_enabled(XPath.button_labelled(u'Edit'))
+    assert not browser.is_element_enabled(XPath.link_with_text('Add address'))
+    assert not browser.is_element_enabled(XPath.button_labelled('Edit'))
 
     # Case: can edit only
     other_address_book.allow(account, can_edit_addresses=True, can_add_addresses=False)
     browser.refresh()
-    assert not browser.is_element_enabled(XPath.link_with_text(u'Add address'))
-    assert browser.is_element_enabled(XPath.button_labelled(u'Edit'))
+    assert not browser.is_element_enabled(XPath.link_with_text('Add address'))
+    assert browser.is_element_enabled(XPath.button_labelled('Edit'))
 
     # Case: can add, and therefor also edit
     other_address_book.allow(account, can_add_addresses=True)
     browser.refresh()
-    assert browser.is_element_enabled(XPath.link_with_text(u'Add address'))
-    assert browser.is_element_enabled(XPath.button_labelled(u'Edit'))
+    assert browser.is_element_enabled(XPath.link_with_text('Add address'))
+    assert browser.is_element_enabled(XPath.button_labelled('Edit'))
     
-    browser.click(XPath.button_labelled(u'Edit'))
-    browser.type(XPath.input_labelled(u'Name'), u'Else')
-    browser.type(XPath.input_labelled(u'Email'), u'else@some.org')
-    browser.click(XPath.button_labelled(u'Update'))
+    browser.click(XPath.button_labelled('Edit'))
+    browser.type(XPath.input_labelled('Name'), 'Else')
+    browser.type(XPath.input_labelled('Email'), 'else@some.org')
+    browser.click(XPath.button_labelled('Update'))
 
-    assert browser.is_element_present(XPath.paragraph_containing(u'Else: else@some.org'))
+    assert browser.is_element_present(XPath.paragraph_containing('Else: else@some.org'))
 
 
 @test(AccessFixture)
@@ -264,28 +268,28 @@ def edit_other(fixture):
 
     other_address_book = fixture.other_address_book
     other_address_book.allow(account, can_edit_addresses=True, can_add_addresses=True)
-    Address(address_book=other_address_book, email_address=u'friend@some.org', name=u'Friend').save()
+    Address(address_book=other_address_book, email_address='friend@some.org', name='Friend').save()
 
     fixture.log_in(browser=browser, system_account=account)
-    browser.open(u'/')
+    browser.open('/')
 
-    browser.click(XPath.link_with_text(u'Address book of other@some.org'))
-    browser.click(XPath.button_labelled(u'Edit'))
+    browser.click(XPath.link_with_text('Address book of other@some.org'))
+    browser.click(XPath.button_labelled('Edit'))
 
     # Case: may edit name
-    assert browser.is_element_enabled(XPath.input_labelled(u'Name'))
-    assert browser.is_element_enabled(XPath.input_labelled(u'Email'))
+    assert browser.is_element_enabled(XPath.input_labelled('Name'))
+    assert browser.is_element_enabled(XPath.input_labelled('Email'))
 
     # Case: may not edit name
     other_address_book.allow(account, can_edit_addresses=True, can_add_addresses=False  )
     browser.refresh()
-    assert not browser.is_element_enabled(XPath.input_labelled(u'Name'))
-    assert browser.is_element_enabled(XPath.input_labelled(u'Email'))
+    assert not browser.is_element_enabled(XPath.input_labelled('Name'))
+    assert browser.is_element_enabled(XPath.input_labelled('Email'))
 
-    browser.type(XPath.input_labelled(u'Email'), u'else@some.org')
-    browser.click(XPath.button_labelled(u'Update'))
+    browser.type(XPath.input_labelled('Email'), 'else@some.org')
+    browser.click(XPath.button_labelled('Update'))
 
-    assert browser.is_element_present(XPath.paragraph_containing(u'Friend: else@some.org'))
+    assert browser.is_element_present(XPath.paragraph_containing('Friend: else@some.org'))
     
 
 @test(AccessFixture)
@@ -299,22 +303,22 @@ def add_collaborator(fixture):
     other_account = fixture.other_account
 
     fixture.log_in(browser=browser, system_account=account)
-    browser.open(u'/')
+    browser.open('/')
 
     assert address_book not in AddressBook.address_books_visible_to(other_account)
     assert not address_book.can_be_edited_by(other_account)
     assert not address_book.can_be_added_to_by(other_account)
 
-    browser.click(XPath.link_with_text(u'Address book of johndoe@some.org'))
-    browser.click(XPath.link_with_text(u'Add collaborator'))
+    browser.click(XPath.link_with_text('Address book of johndoe@some.org'))
+    browser.click(XPath.link_with_text('Add collaborator'))
 
-    browser.select(XPath.select_labelled(u'Choose collaborator'), u'other@some.org')
-    browser.click(XPath.input_labelled(u'May add new addresses'))
-    browser.click(XPath.input_labelled(u'May edit existing addresses'))
+    browser.select(XPath.select_labelled('Choose collaborator'), 'other@some.org')
+    browser.click(XPath.input_labelled('May add new addresses'))
+    browser.click(XPath.input_labelled('May edit existing addresses'))
 
-    browser.click(XPath.button_labelled(u'Share'))
+    browser.click(XPath.button_labelled('Share'))
 
-    assert fixture.is_on_address_book_page_of(u'johndoe@some.org')
+    assert fixture.is_on_address_book_page_of('johndoe@some.org')
 
     assert address_book in AddressBook.address_books_visible_to(other_account)
     assert address_book.can_be_edited_by(other_account)
@@ -325,27 +329,27 @@ class ViewScenarios(AccessFixture):
     @scenario
     def viewing_other_address_book(self):
         self.other_address_book; Session.flush()
-        self.url = u'/address_book/%s' % self.other_address_book.id
+        self.url = '/address_book/%s' % self.other_address_book.id
         self.get = True
 
     @scenario
     def add_address_to_other_address_book(self):
         self.other_address_book; Session.flush()
-        self.url = u'/add_address/%s' % self.other_address_book.id
+        self.url = '/add_address/%s' % self.other_address_book.id
         self.get = False
 
     @scenario
     def edit_address_in_other_address_book(self):
-        address = Address(address_book=self.other_address_book, email_address=u'somefriend@some.org', name=u'Friend')
+        address = Address(address_book=self.other_address_book, email_address='somefriend@some.org', name='Friend')
         address.save()
         Session.flush()
-        self.url = u'/edit_address/%s' % address.id
+        self.url = '/edit_address/%s' % address.id
         self.get = True
 
     @scenario
     def add_collaborator_to_other_address_book(self):
         self.other_address_book; Session.flush()
-        self.url = u'/add_collaborator/%s' % self.other_address_book.id
+        self.url = '/add_collaborator/%s' % self.other_address_book.id
         self.get = True
 
 
