@@ -7,6 +7,8 @@
 
 
 
+from __future__ import unicode_literals
+from __future__ import print_function
 from reahl.tofu import test, set_up
 from reahl.web_dev.fixtures import WebFixture
 from reahl.webdev.tools import Browser, XPath
@@ -20,9 +22,9 @@ class AccessFixture(WebFixture):
     def new_browser(self):
         return Browser(self.new_wsgi_app(site_root=AddressBookUI))
         
-    password = u'bobbejaan'
+    password = 'bobbejaan'
 
-    def new_account(self, email=u'johndoe@some.org'):
+    def new_account(self, email='johndoe@some.org'):
         account = EmailAndPasswordSystemAccount(email=email)
         account.set_new_password(account.email, self.password)
         account.activate()
@@ -33,13 +35,13 @@ class AccessFixture(WebFixture):
         return AddressBook(owner=owner)
 
     def new_other_account(self):
-        return self.new_account(email=u'other@some.org')
+        return self.new_account(email='other@some.org')
         
     def new_other_address_book(self):
         return self.new_address_book(owner=self.other_account)
 
     def is_on_address_book_page_of(self, email):
-        return self.browser.title == u'Address book of %s' % email
+        return self.browser.title == 'Address book of %s' % email
 
 
 class DemoFixture(AccessFixture):
@@ -48,31 +50,31 @@ class DemoFixture(AccessFixture):
     def do_demo_setup(self):
         self.address_book
         john = self.account
-        jane = self.new_account(email=u'janedoe@some.org')
+        jane = self.new_account(email='janedoe@some.org')
         jane_book = self.new_address_book(owner=jane)
-        someone = self.new_account(email=u'someone@some.org')
+        someone = self.new_account(email='someone@some.org')
         someone_book = self.new_address_book(owner=someone)
-        someone_else = self.new_account(email=u'someoneelse@some.org')
+        someone_else = self.new_account(email='someoneelse@some.org')
         someone_else_book = self.new_address_book(owner=someone_else)
 
         jane_book.allow(john, can_add_addresses=True, can_edit_addresses=True)
         someone_book.allow(john, can_add_addresses=False, can_edit_addresses=True)
         someone_else_book.allow(john, can_add_addresses=False, can_edit_addresses=False)
         
-        Address(address_book=jane_book, email_address=u'friend1@some.org', name=u'Friend1').save()
-        Address(address_book=jane_book, email_address=u'friend2@some.org', name=u'Friend2').save()
-        Address(address_book=jane_book, email_address=u'friend3@some.org', name=u'Friend3').save()
-        Address(address_book=jane_book, email_address=u'friend4@some.org', name=u'Friend4').save()
+        Address(address_book=jane_book, email_address='friend1@some.org', name='Friend1').save()
+        Address(address_book=jane_book, email_address='friend2@some.org', name='Friend2').save()
+        Address(address_book=jane_book, email_address='friend3@some.org', name='Friend3').save()
+        Address(address_book=jane_book, email_address='friend4@some.org', name='Friend4').save()
 
-        Address(address_book=someone_book, email_address=u'friend11@some.org', name=u'Friend11').save()
-        Address(address_book=someone_book, email_address=u'friend12@some.org', name=u'Friend12').save()
-        Address(address_book=someone_book, email_address=u'friend13@some.org', name=u'Friend13').save()
-        Address(address_book=someone_book, email_address=u'friend14@some.org', name=u'Friend14').save()
+        Address(address_book=someone_book, email_address='friend11@some.org', name='Friend11').save()
+        Address(address_book=someone_book, email_address='friend12@some.org', name='Friend12').save()
+        Address(address_book=someone_book, email_address='friend13@some.org', name='Friend13').save()
+        Address(address_book=someone_book, email_address='friend14@some.org', name='Friend14').save()
 
-        Address(address_book=someone_else_book, email_address=u'friend21@some.org', name=u'Friend21').save()
-        Address(address_book=someone_else_book, email_address=u'friend22@some.org', name=u'Friend22').save()
-        Address(address_book=someone_else_book, email_address=u'friend23@some.org', name=u'Friend23').save()
-        Address(address_book=someone_else_book, email_address=u'friend24@some.org', name=u'Friend24').save()
+        Address(address_book=someone_else_book, email_address='friend21@some.org', name='Friend21').save()
+        Address(address_book=someone_else_book, email_address='friend22@some.org', name='Friend22').save()
+        Address(address_book=someone_else_book, email_address='friend23@some.org', name='Friend23').save()
+        Address(address_book=someone_else_book, email_address='friend24@some.org', name='Friend24').save()
         Session.flush()
 
 
@@ -94,10 +96,10 @@ def separate_address_books(fixture):
     assert address_book.addresses == []
     assert other_address_book.addresses == []
 
-    address1 = Address(address_book=address_book, email_address=u'friend1@some.org', name=u'Friend1')
-    address2 = Address(address_book=address_book, email_address=u'friend2@some.org', name=u'Friend2')
+    address1 = Address(address_book=address_book, email_address='friend1@some.org', name='Friend1')
+    address2 = Address(address_book=address_book, email_address='friend2@some.org', name='Friend2')
 
-    address3 = Address(address_book=other_address_book, email_address=u'friend3@some.org', name=u'Friend3')
+    address3 = Address(address_book=other_address_book, email_address='friend3@some.org', name='Friend3')
 
     for address in [address1, address2, address3]:
         address.save()
@@ -115,7 +117,7 @@ def collaborators(fixture):
     address_book = fixture.address_book
     other_address_book = fixture.other_address_book
 
-    unrelated_account = fixture.new_account(email=u'unrelated@some.org')
+    unrelated_account = fixture.new_account(email='unrelated@some.org')
     unrelated_address_book = fixture.new_address_book(owner=unrelated_account)
     
     other_address_book.allow(account)
@@ -127,7 +129,7 @@ def collaborators(fixture):
 
     # Getting a list of visible AddressBooks (for populating the screen)
     books = AddressBook.address_books_visible_to(account)
-    assert set(books) == set([address_book, other_address_book])
+    assert set(books) == {address_book, other_address_book}
 
 
 @test(AccessFixture)
@@ -172,13 +174,13 @@ def logging_in(fixture):
     other_address_book = fixture.other_address_book
     other_address_book.allow(account)
 
-    browser.open(u'/')
-    browser.type(XPath.input_labelled(u'Email'), u'johndoe@some.org')
-    browser.type(XPath.input_labelled(u'Password'), fixture.password)
-    browser.click(XPath.button_labelled(u'Log in'))
+    browser.open('/')
+    browser.type(XPath.input_labelled('Email'), 'johndoe@some.org')
+    browser.type(XPath.input_labelled('Password'), fixture.password)
+    browser.click(XPath.button_labelled('Log in'))
     
-    assert browser.is_element_present(XPath.link_with_text(u'Address book of johndoe@some.org'))
-    assert browser.is_element_present(XPath.link_with_text(u'Address book of other@some.org'))
+    assert browser.is_element_present(XPath.link_with_text('Address book of johndoe@some.org'))
+    assert browser.is_element_present(XPath.link_with_text('Address book of other@some.org'))
 
 
 @test(AccessFixture)
@@ -189,25 +191,25 @@ def edit_and_add_own(fixture):
     address_book = fixture.address_book
 
     fixture.log_in(browser=browser, system_account=account)
-    browser.open(u'/')
+    browser.open('/')
     
-    browser.click(XPath.link_with_text(u'Address book of johndoe@some.org'))
+    browser.click(XPath.link_with_text('Address book of johndoe@some.org'))
     
     # add
-    browser.click(XPath.link_with_text(u'Add address'))
-    browser.type(XPath.input_labelled(u'Name'), u'Someone')
-    browser.type(XPath.input_labelled(u'Email'), u'someone@some.org')
-    browser.click(XPath.button_labelled(u'Save'))
+    browser.click(XPath.link_with_text('Add address'))
+    browser.type(XPath.input_labelled('Name'), 'Someone')
+    browser.type(XPath.input_labelled('Email'), 'someone@some.org')
+    browser.click(XPath.button_labelled('Save'))
 
-    assert browser.is_element_present(XPath.paragraph_containing(u'Someone: someone@some.org'))
+    assert browser.is_element_present(XPath.paragraph_containing('Someone: someone@some.org'))
 
     # edit
-    browser.click(XPath.button_labelled(u'Edit'))
-    browser.type(XPath.input_labelled(u'Name'), u'Else')
-    browser.type(XPath.input_labelled(u'Email'), u'else@some.org')
-    browser.click(XPath.button_labelled(u'Update'))
+    browser.click(XPath.button_labelled('Edit'))
+    browser.type(XPath.input_labelled('Name'), 'Else')
+    browser.type(XPath.input_labelled('Email'), 'else@some.org')
+    browser.click(XPath.button_labelled('Update'))
 
-    assert browser.is_element_present(XPath.paragraph_containing(u'Else: else@some.org'))
+    assert browser.is_element_present(XPath.paragraph_containing('Else: else@some.org'))
     
 
 @test(AccessFixture)
@@ -221,22 +223,22 @@ def add_collaborator(fixture):
     other_account = fixture.other_account
 
     fixture.log_in(browser=browser, system_account=account)
-    browser.open(u'/')
+    browser.open('/')
 
     assert address_book not in AddressBook.address_books_visible_to(other_account)
     assert not address_book.can_be_edited_by(other_account)
     assert not address_book.can_be_added_to_by(other_account)
 
-    browser.click(XPath.link_with_text(u'Address book of johndoe@some.org'))
-    browser.click(XPath.link_with_text(u'Add collaborator'))
+    browser.click(XPath.link_with_text('Address book of johndoe@some.org'))
+    browser.click(XPath.link_with_text('Add collaborator'))
 
-    browser.select(XPath.select_labelled(u'Choose collaborator'), u'other@some.org')
-    browser.click(XPath.input_labelled(u'May add new addresses'))
-    browser.click(XPath.input_labelled(u'May edit existing addresses'))
+    browser.select(XPath.select_labelled('Choose collaborator'), 'other@some.org')
+    browser.click(XPath.input_labelled('May add new addresses'))
+    browser.click(XPath.input_labelled('May edit existing addresses'))
 
-    browser.click(XPath.button_labelled(u'Share'))
+    browser.click(XPath.button_labelled('Share'))
 
-    assert fixture.is_on_address_book_page_of(u'johndoe@some.org')
+    assert fixture.is_on_address_book_page_of('johndoe@some.org')
 
     assert address_book in AddressBook.address_books_visible_to(other_account)
     assert address_book.can_be_edited_by(other_account)
