@@ -1,22 +1,24 @@
 
 
+from __future__ import unicode_literals
+from __future__ import print_function
 import elixir
 
 from reahl.sqlalchemysupport import Session, metadata
 
-from reahl.web.fw import UserInterface
+from reahl.web.fw import UserInterface, Widget
 from reahl.web.ui import TwoColumnPage, Form, TextInput, LabelledBlockInput, Button, Panel, P, H, InputGroup
 from reahl.component.modelinterface import exposed, EmailField, Field, Event, Action
 
 
 class AddressBookUI(UserInterface):
     def assemble(self):
-        self.define_view(u'/', title=u'Addresses', page=AddressBookPage.factory())
+        self.define_view('/', title='Addresses', page=AddressBookPage.factory())
 
 
 class AddressBookPage(TwoColumnPage):
     def __init__(self, view):
-        super(AddressBookPage, self).__init__(view, style=u'basic')
+        super(AddressBookPage, self).__init__(view, style='basic')
         self.main.add_child(AddressBookPanel(view))
 
 
@@ -24,7 +26,7 @@ class AddressBookPanel(Panel):
     def __init__(self, view):
         super(AddressBookPanel, self).__init__(view)
 
-        self.add_child(H(view, 1, text=u'Addresses'))
+        self.add_child(H(view, 1, text='Addresses'))
         
         for address in Address.query.all():
             self.add_child(AddressBox(view, address))
@@ -34,11 +36,11 @@ class AddressBookPanel(Panel):
 
 class AddAddressForm(Form):
     def __init__(self, view):
-        super(AddAddressForm, self).__init__(view, u'add_form')
+        super(AddAddressForm, self).__init__(view, 'add_form')
 
         new_address = Address()
 
-        grouped_inputs = self.add_child(InputGroup(view, label_text=u'Add an address'))
+        grouped_inputs = self.add_child(InputGroup(view, label_text='Add an address'))
         grouped_inputs.add_child( LabelledBlockInput(TextInput(self, new_address.fields.name)) )
         grouped_inputs.add_child( LabelledBlockInput(TextInput(self, new_address.fields.email_address)) )
 
@@ -46,10 +48,10 @@ class AddAddressForm(Form):
         grouped_inputs.add_child(Button(self, new_address.events.save))
 
 
-class AddressBox(Panel):
+class AddressBox(Widget):
     def __init__(self, view, address):
         super(AddressBox, self).__init__(view)
-        self.add_child(P(view, text=u'%s: %s' % (address.name, address.email_address)))
+        self.add_child(P(view, text='%s: %s' % (address.name, address.email_address)))
 
 
 class Address(elixir.Entity):
@@ -61,13 +63,13 @@ class Address(elixir.Entity):
 
     @exposed
     def fields(self, fields):
-        fields.name = Field(label=u'Name', required=True)
-        fields.email_address = EmailField(label=u'Email', required=True)
+        fields.name = Field(label='Name', required=True)
+        fields.email_address = EmailField(label='Email', required=True)
 
     def save(self):
         Session.add(self)
         
     @exposed
     def events(self, events):
-        events.save = Event(label=u'Save', action=Action(self.save))
+        events.save = Event(label='Save', action=Action(self.save))
 
