@@ -1,4 +1,6 @@
 
+from __future__ import unicode_literals
+from __future__ import print_function
 from helloapache import HelloUI
 
 # The UserInterface class acting as the root of the URL hierachy of your application:
