@@ -1,5 +1,7 @@
 
 # In production this has to be set, to the name of the egg of your application:
+from __future__ import unicode_literals
+from __future__ import print_function
 reahlsystem.root_egg = 'hellonginx'   
 
 # If using SQLite:
