@@ -1,6 +1,8 @@
 
 
 
+from __future__ import unicode_literals
+from __future__ import print_function
 from reahl.tofu import test
 
 from reahl.web_dev.fixtures import WebFixture
@@ -15,7 +17,7 @@ class JobsFixture(WebFixture):
         return super(JobsFixture, self).new_wsgi_app(site_root=AddressBookUI)
         
     def new_existing_address(self):
-        address = Address(name=u'John Doe', email_address=u'johndoe@some.org')
+        address = Address(name='John Doe', email_address='johndoe@some.org')
         address.save()
         return address
 
@@ -23,8 +25,8 @@ class JobsFixture(WebFixture):
         return Browser(self.wsgi_app)
 
     def address_is_listed_as(self, name, email_address, is_new):
-        new = u' (new)' if is_new else u''
-        return self.browser.is_element_present(XPath.paragraph_containing(u'%s: %s%s' % (name, email_address, new)))
+        new = ' (new)' if is_new else ''
+        return self.browser.is_element_present(XPath.paragraph_containing('%s: %s%s' % (name, email_address, new)))
 
 
 @test(JobsFixture)
@@ -32,13 +34,13 @@ def add_address(fixture):
     """A user can add an address, after which the address is listed."""
     browser = fixture.browser
     
-    browser.open(u'/')
-    browser.type(XPath.input_labelled(u'Name'), u'John')
-    browser.type(XPath.input_labelled(u'Email'), u'johndoe@some.org')
+    browser.open('/')
+    browser.type(XPath.input_labelled('Name'), 'John')
+    browser.type(XPath.input_labelled('Email'), 'johndoe@some.org')
 
-    browser.click(XPath.button_labelled(u'Save'))
+    browser.click(XPath.button_labelled('Save'))
     
-    assert fixture.address_is_listed_as(u'John', u'johndoe@some.org', True)
+    assert fixture.address_is_listed_as('John', 'johndoe@some.org', True)
 
 
 @test(JobsFixture)
