@@ -1,6 +1,8 @@
 
 
 
+from __future__ import unicode_literals
+from __future__ import print_function
 from reahl.web.fw import UserInterface
 from reahl.web.ui import TwoColumnPage, Form, TextInput, LabelledBlockInput, Button, Panel, P, H, InputGroup, HMenu,\
                          PasswordInput, ErrorFeedbackMessage
@@ -10,13 +12,13 @@ from reahl.systemaccountmodel import AccountManagementInterface, UserSession
 
 class MenuPage(TwoColumnPage):
     def __init__(self, view, main_bookmarks):
-        super(MenuPage, self).__init__(view, style=u'basic')
+        super(MenuPage, self).__init__(view, style='basic')
         self.header.add_child(HMenu.from_bookmarks(view, main_bookmarks))
 
 
 class LoginForm(Form):
     def __init__(self, view):
-        super(LoginForm, self).__init__(view, u'login')
+        super(LoginForm, self).__init__(view, 'login')
         
         accounts = AccountManagementInterface.for_current_session()
 
@@ -36,13 +38,13 @@ class LoginUI(UserInterface):
         if user_session.account:
             logged_in_as = user_session.account.email
         else:
-            logged_in_as = u'Guest'
+            logged_in_as = 'Guest'
 
-        home = self.define_view(u'/', title=u'Home')
-        home.set_slot(u'main', P.factory(text=u'Welcome %s' % logged_in_as))
+        home = self.define_view('/', title='Home')
+        home.set_slot('main', P.factory(text='Welcome %s' % logged_in_as))
 
-        login_page = self.define_view(u'/login', title=u'Log in')
-        login_page.set_slot(u'main', LoginForm.factory())
+        login_page = self.define_view('/login', title='Log in')
+        login_page.set_slot('main', LoginForm.factory())
         
         bookmarks = [i.as_bookmark(self) for i in [home, login_page]]
         self.define_page(MenuPage, bookmarks)
