@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from __future__ import print_function
 from reahl.tofu import test
 
 from reahl.web_dev.fixtures import WebFixture
@@ -11,7 +13,7 @@ class AddressAppErrorFixture(WebFixture):
         return super(AddressAppErrorFixture, self).new_wsgi_app(site_root=AddressBookUI, enable_js=True)
         
     def new_existing_address(self):
-        address = Address(name=u'John Doe', email_address=u'johndoe@some.org')
+        address = Address(name='John Doe', email_address='johndoe@some.org')
         address.save()
         return address
 
@@ -26,12 +28,12 @@ def edit_errors(fixture):
     browser = fixture.driver_browser
     existing_address = fixture.existing_address # Doing this just creates the Address in the database
     
-    browser.open(u'/')
-    browser.click(XPath.button_labelled(u'Edit'))
+    browser.open('/')
+    browser.click(XPath.button_labelled('Edit'))
     
-    browser.type(XPath.input_labelled(u'Email'), u'invalid email address')
+    browser.type(XPath.input_labelled('Email'), 'invalid email address')
 
-    assert fixture.error_is_displayed(u'Email should be a valid email address')
+    assert fixture.error_is_displayed('Email should be a valid email address')
 
 
 
