@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from __future__ import print_function
 import hashlib
 
 import elixir
@@ -9,7 +11,11 @@ from reahl.component.exceptions import DomainException
 from reahl.web.fw import UserInterface
 from reahl.web.ui import TwoColumnPage, Form, TextInput, LabelledBlockInput, Button, Panel, P, H, InputGroup, HMenu,\
                          PasswordInput, ErrorFeedbackMessage
-from reahl.component.modelinterface import exposed, EmailField, Field, Event, Action, PasswordField
+from reahl.component.modelinterface import Action
+from reahl.component.modelinterface import EmailField
+from reahl.component.modelinterface import Event
+from reahl.component.modelinterface import PasswordField
+from reahl.component.modelinterface import exposed
 
 
 
@@ -29,19 +35,19 @@ class User(elixir.Entity):
 
 @session_scoped
 class LoginSession(elixir.Entity):
-    elixir.using_options(session=Session, metadata=metadata, tablename=u'tutorial_loginsession')
+    elixir.using_options(session=Session, metadata=metadata, tablename='tutorial_loginsession')
 
     current_user = elixir.ManyToOne(User)
     email_address = elixir.Field(elixir.UnicodeText)
 
     @exposed
     def fields(self, fields):
-        fields.email_address = EmailField(label=u'Email', required=True)
-        fields.password = PasswordField(label=u'Password', required=True)
+        fields.email_address = EmailField(label='Email', required=True)
+        fields.password = PasswordField(label='Password', required=True)
 
     @exposed
     def events(self, events):
-        events.log_in = Event(label=u'Log in', action=Action(self.log_in))
+        events.log_in = Event(label='Log in', action=Action(self.log_in))
 
     def log_in(self):
         user = User.query.filter_by(email_address=self.email_address).one()
@@ -54,19 +60,19 @@ class LoginSession(elixir.Entity):
 
 class MenuPage(TwoColumnPage):
     def __init__(self, view, main_bookmarks):
-        super(MenuPage, self).__init__(view, style=u'basic')
+        super(MenuPage, self).__init__(view, style='basic')
         self.header.add_child(HMenu.from_bookmarks(view, main_bookmarks))
 
 
 class InvalidPassword(DomainException):
     def as_user_message(self):
-        return u'The email/password given do not match.'
+        return 'The email/password given do not match.'
     
 
 
 class LoginForm(Form):
     def __init__(self, view, login_session):
-        super(LoginForm, self).__init__(view, u'login')
+        super(LoginForm, self).__init__(view, 'login')
         
         if self.exception:
             self.add_child(ErrorFeedbackMessage(view, self.exception.as_user_message()))
@@ -84,14 +90,14 @@ class SessionScopeUI(UserInterface):
         if login_session.current_user:
             user_name = login_session.current_user.name
         else:
-            user_name = u'Guest'
+            user_name = 'Guest'
 
-        home = self.define_view(u'/', title=u'Home')
-        home.set_slot(u'main', P.factory(text=u'Welcome %s' % user_name))
+        home = self.define_view('/', title='Home')
+        home.set_slot('main', P.factory(text='Welcome %s' % user_name))
 
        
-        login_page = self.define_view(u'/login', title=u'Log in')
-        login_page.set_slot(u'main', LoginForm.factory(login_session))
+        login_page = self.define_view('/login', title='Log in')
+        login_page.set_slot('main', LoginForm.factory(login_session))
         
         bookmarks = [i.as_bookmark(self) for i in [home, login_page]]
         self.define_page(MenuPage, bookmarks)
