@@ -1,8 +1,10 @@
+from __future__ import unicode_literals
+from __future__ import print_function
 from reahl.tofu import test, Fixture
 
 class SimpleFixture(Fixture):
     def new_name(self):
-        return u'John'
+        return 'John'
 
 
 @test(SimpleFixture)
@@ -10,7 +12,7 @@ def fixture_singletons(fixture):
     """Accessing an attribute on the Fixture always brings back the same 
        object, as created by a similarly named new_ method on the fixture."""
 
-    assert fixture.name == u'John'
+    assert fixture.name == 'John'
     assert fixture.name is fixture.name  # ie, the same object is always returned
 
 
@@ -42,11 +44,11 @@ class MoreInterestingFixture(SimpleFixture):
 @test(MoreInterestingFixture)
 def bypassing_the_singleton(fixture):
     """new_ methods can be supplied with kwargs in order to create test objects that differ from the default."""
-    jane = fixture.new_user(name=u'Jane')
-    assert jane.name == u'Jane'
+    jane = fixture.new_user(name='Jane')
+    assert jane.name == 'Jane'
     assert fixture.user is not jane
 
-    other_jane = fixture.new_user(name=u'Jane')
+    other_jane = fixture.new_user(name='Jane')
     assert jane is not other_jane
 
 
