@@ -15,6 +15,8 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
+from __future__ import unicode_literals
+from __future__ import print_function
 import elixir
 
 from reahl.sqlalchemysupport import Session, metadata
@@ -27,9 +29,9 @@ from reahl.component.modelinterface import exposed, EmailField, Field, Event, Ac
 
 class FileUploadUI(UserInterface):
     def assemble(self):
-        self.define_page(TwoColumnPage, style=u'basic')
-        home = self.define_view(u'/', title=u'File upload demo')
-        home.set_slot(u'main', CommentPostPanel.factory())
+        self.define_page(TwoColumnPage, style='basic')
+        home = self.define_view('/', title='File upload demo')
+        home.set_slot('main', CommentPostPanel.factory())
 
 
 class Comment(elixir.Entity):
@@ -38,17 +40,17 @@ class Comment(elixir.Entity):
     
     email_address  = elixir.Field(elixir.UnicodeText)
     text           = elixir.Field(elixir.UnicodeText)
-    attached_files = elixir.OneToMany(u'AttachedFile')
+    attached_files = elixir.OneToMany('AttachedFile')
     
     @exposed
     def fields(self, fields):
-        fields.email_address = EmailField(label=u'Email address', required=True)
-        fields.text          = Field(label=u'Comment', required=True)
-        fields.uploaded_files = FileField(allow_multiple=True, max_size_bytes=4*1000*1000, max_files=4, accept=[u'text/*'])
+        fields.email_address = EmailField(label='Email address', required=True)
+        fields.text          = Field(label='Comment', required=True)
+        fields.uploaded_files = FileField(allow_multiple=True, max_size_bytes=4*1000*1000, max_files=4, accept=['text/*'])
 
     @exposed
     def events(self, events):
-        events.submit = Event(label=u'Submit', action=Action(self.submit))
+        events.submit = Event(label='Submit', action=Action(self.submit))
 
     def attach_uploaded_files(self):
         for f in self.uploaded_files:
@@ -78,24 +80,24 @@ class CommentPostPanel(Panel):
 
 class CommentForm(Form):
     def __init__(self, view):
-        super(CommentForm, self).__init__(view, u'myform')
+        super(CommentForm, self).__init__(view, 'myform')
 
         new_comment = Comment()
-        self.add_child(H(view, 1, text=u'Leave a comment'))
+        self.add_child(H(view, 1, text='Leave a comment'))
         self.add_child(LabelledBlockInput(TextInput(self, new_comment.fields.email_address)))
         self.add_child(LabelledBlockInput(TextInput(self, new_comment.fields.text)))
 
-        attachments = self.add_child(InputGroup(view, label_text=u'Attach files'))
+        attachments = self.add_child(InputGroup(view, label_text='Attach files'))
         attachments.add_child(FileUploadInput(self, new_comment.fields.uploaded_files))
 
         self.define_event_handler(new_comment.events.submit)
-        buttons = self.add_child(InputGroup(view, label_text=u' '))
+        buttons = self.add_child(InputGroup(view, label_text=' '))
         buttons.add_child(Button(self, new_comment.events.submit))
 
 
 class CommentBox(Panel):
     def __init__(self, view, comment):
         super(CommentBox, self).__init__(view)
-        self.add_child(P(view, text=u'By %s: %s' % (comment.email_address, comment.text)))
+        self.add_child(P(view, text='By %s: %s' % (comment.email_address, comment.text)))
         
 
